@@ -9,6 +9,7 @@ from groundx.apis.paths.v1_ingest_documents_id import V1IngestDocumentsId
 from groundx.apis.paths.v1_ingest_documents import V1IngestDocuments
 from groundx.apis.paths.v1_ingest_document_document_id import V1IngestDocumentDocumentId
 from groundx.apis.paths.v1_search_id import V1SearchId
+from groundx.apis.paths.v1_search_documents import V1SearchDocuments
 from groundx.apis.paths.v1_project import V1Project
 from groundx.apis.paths.v1_project_project_id import V1ProjectProjectId
 from groundx.apis.paths.v1_project_project_id_bucket_bucket_id import V1ProjectProjectIdBucketBucketId
@@ -29,6 +30,7 @@ PathToApi = typing_extensions.TypedDict(
         PathValues.V1_INGEST_DOCUMENTS: V1IngestDocuments,
         PathValues.V1_INGEST_DOCUMENT_DOCUMENT_ID: V1IngestDocumentDocumentId,
         PathValues.V1_SEARCH_ID: V1SearchId,
+        PathValues.V1_SEARCH_DOCUMENTS: V1SearchDocuments,
         PathValues.V1_PROJECT: V1Project,
         PathValues.V1_PROJECT_PROJECT_ID: V1ProjectProjectId,
         PathValues.V1_PROJECT_PROJECT_ID_BUCKET_BUCKET_ID: V1ProjectProjectIdBucketBucketId,
@@ -50,6 +52,7 @@ path_to_api = PathToApi(
         PathValues.V1_INGEST_DOCUMENTS: V1IngestDocuments,
         PathValues.V1_INGEST_DOCUMENT_DOCUMENT_ID: V1IngestDocumentDocumentId,
         PathValues.V1_SEARCH_ID: V1SearchId,
+        PathValues.V1_SEARCH_DOCUMENTS: V1SearchDocuments,
         PathValues.V1_PROJECT: V1Project,
         PathValues.V1_PROJECT_PROJECT_ID: V1ProjectProjectId,
         PathValues.V1_PROJECT_PROJECT_ID_BUCKET_BUCKET_ID: V1ProjectProjectIdBucketBucketId,
