@@ -5,7 +5,8 @@ from groundx.apis.tags.documents_api import DocumentsApi
 from groundx.apis.tags.search_api import SearchApi
 from groundx.apis.tags.projects_api import ProjectsApi
 from groundx.apis.tags.buckets_api import BucketsApi
-from groundx.apis.tags.test_api import TestApi
+from groundx.apis.tags.customer_api import CustomerApi
+from groundx.apis.tags.health_api import HealthApi
 
 TagToApi = typing_extensions.TypedDict(
     'TagToApi',
@@ -14,7 +15,8 @@ TagToApi = typing_extensions.TypedDict(
         TagValues.SEARCH: SearchApi,
         TagValues.PROJECTS: ProjectsApi,
         TagValues.BUCKETS: BucketsApi,
-        TagValues.TEST: TestApi,
+        TagValues.CUSTOMER: CustomerApi,
+        TagValues.HEALTH: HealthApi,
     }
 )
 
@@ -24,6 +26,7 @@ tag_to_api = TagToApi(
         TagValues.SEARCH: SearchApi,
         TagValues.PROJECTS: ProjectsApi,
         TagValues.BUCKETS: BucketsApi,
-        TagValues.TEST: TestApi,
+        TagValues.CUSTOMER: CustomerApi,
+        TagValues.HEALTH: HealthApi,
     }
 )
