@@ -1,13 +1,13 @@
 # coding: utf-8
 
 """
-    GroundX API
+    GroundX APIs
 
-    Ground Your RAG Apps in Fact not Fiction
+    RAG Made Simple, Secure and Hallucination Free
 
-    The version of the OpenAPI document: 1.0.0
-    Contact: support@groundx.ai
-    Created by: https://www.groundx.ai/
+    The version of the OpenAPI document: 1.3.26
+    Contact: support@eyelevel.ai
+    Created by: https://www.eyelevel.ai/
 """
 
 from datetime import datetime, date
@@ -23,6 +23,7 @@ class RequiredProcessStatusResponseIngest(TypedDict):
 
     status: ProcessingStatus
 
+
 class OptionalProcessStatusResponseIngest(TypedDict, total=False):
     progress: ProcessStatusResponseIngestProgress
 
