@@ -1,13 +1,13 @@
 # coding: utf-8
 
 """
-    GroundX API
+    GroundX APIs
 
-    Ground Your RAG Apps in Fact not Fiction
+    RAG Made Simple, Secure and Hallucination Free
 
-    The version of the OpenAPI document: 1.0.0
-    Contact: support@groundx.ai
-    Created by: https://www.groundx.ai/
+    The version of the OpenAPI document: 1.3.26
+    Contact: support@eyelevel.ai
+    Created by: https://www.eyelevel.ai/
 """
 
 from datetime import datetime, date
@@ -15,13 +15,13 @@ import typing
 from enum import Enum
 from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
-from groundx.type.document_response import DocumentResponse
+from groundx.type.document_detail import DocumentDetail
 
 class RequiredProcessStatusResponseIngestProgressErrors(TypedDict):
     pass
 
 class OptionalProcessStatusResponseIngestProgressErrors(TypedDict, total=False):
-    documents: typing.List[DocumentResponse]
+    documents: typing.List[DocumentDetail]
 
     total: int
 
