@@ -1,13 +1,13 @@
 # coding: utf-8
 
 """
-    GroundX API
+    GroundX APIs
 
-    Ground Your RAG Apps in Fact not Fiction
+    RAG Made Simple, Secure and Hallucination Free
 
-    The version of the OpenAPI document: 1.0.0
-    Contact: support@groundx.ai
-    Created by: https://www.groundx.ai/
+    The version of the OpenAPI document: 1.3.26
+    Contact: support@eyelevel.ai
+    Created by: https://www.eyelevel.ai/
 """
 
 from datetime import datetime, date
@@ -20,6 +20,7 @@ from groundx.type.bucket_detail import BucketDetail
 class RequiredProjectDetail(TypedDict):
     projectId: int
 
+
 class OptionalProjectDetail(TypedDict, total=False):
     # The content buckets associated with the project
     buckets: typing.List[BucketDetail]
