@@ -1,13 +1,13 @@
 # coding: utf-8
 
 """
-    GroundX API
+    GroundX APIs
 
-    Ground Your RAG Apps in Fact not Fiction
+    RAG Made Simple, Secure and Hallucination Free
 
-    The version of the OpenAPI document: 1.0.0
-    Contact: support@groundx.ai
-    Created by: https://www.groundx.ai/
+    The version of the OpenAPI document: 1.3.26
+    Contact: support@eyelevel.ai
+    Created by: https://www.eyelevel.ai/
 """
 
 from datetime import datetime, date
@@ -17,6 +17,7 @@ from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
 
 class RequiredProjectUpdateRequest(TypedDict):
+    # The new name of the project being renamed.
     newName: str
 
 class OptionalProjectUpdateRequest(TypedDict, total=False):
