@@ -1,19 +1,19 @@
 # coding: utf-8
 
 """
-    GroundX API
+    GroundX APIs
 
-    Ground Your RAG Apps in Fact not Fiction
+    RAG Made Simple, Secure and Hallucination Free
 
-    The version of the OpenAPI document: 1.0.0
-    Contact: support@groundx.ai
-    Created by: https://www.groundx.ai/
+    The version of the OpenAPI document: 1.3.26
+    Contact: support@eyelevel.ai
+    Created by: https://www.eyelevel.ai/
 """
 
 from datetime import datetime, date
 import typing
 from enum import Enum
-from typing_extensions import TypedDict, Literal
+from typing_extensions import TypedDict, Literal, TYPE_CHECKING
 
 from groundx.type.search_result_item import SearchResultItem
 
@@ -24,15 +24,19 @@ class OptionalSearchResponseSearch(TypedDict, total=False):
     # Total results
     count: int
 
+    # Search results
     results: typing.List[SearchResultItem]
 
-    # The search query
+    # The original search request query
     query: str
 
-    # Top result relevance score
+    # Confidence score in the search results
     score: typing.Union[int, float]
 
-    # Combined text from results
+    # The actual search query, if the search request query was re-written
+    searchQuery: str
+
+    # Suggested context for LLM completion
     text: str
 
     # For paginated results
